tui

package
v1.3.7 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: May 11, 2026 License: AGPL-3.0 Imports: 45 Imported by: 0

Documentation

Overview

Package tui is the top-level Bubble Tea application model.

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func DeleteSwap

func DeleteSwap(swpPath string)

DeleteSwap removes the swap file, ignoring not-found errors.

func NewApp

func NewApp(cfg *config.Config) appModel

NewApp creates and initialises the root application model.

func Run

func Run(cfg *config.Config) error

Run starts the TUI application, restarting automatically if a panic occurs.

Types

This section is empty.

Directories

Path Synopsis
Package bookmarkeditor is a TUI component for editing vault bookmarks.
Package bookmarkeditor is a TUI component for editing vault bookmarks.
Package cmdbar is the command/status bar TUI component.
Package cmdbar is the command/status bar TUI component.
Package common holds shared types and styles used across TUI components.
Package common holds shared types and styles used across TUI components.
Package dialog is a modal yes/no confirmation dialog TUI component.
Package dialog is a modal yes/no confirmation dialog TUI component.
Package palette is the command-palette TUI component.
Package palette is the command-palette TUI component.
Package searchmodal is the full-text search modal TUI component.
Package searchmodal is the full-text search modal TUI component.
Package settingseditor provides a modal TUI component for editing Fern config settings.
Package settingseditor provides a modal TUI component for editing Fern config settings.
Package sidebar is the file-browser sidebar TUI component.
Package sidebar is the file-browser sidebar TUI component.
Package tabcomplete provides filesystem path completion and tab-cycling helpers for TUI input fields.
Package tabcomplete provides filesystem path completion and tab-cycling helpers for TUI input fields.
Package templateprompt is a TUI prompt for selecting note templates.
Package templateprompt is a TUI prompt for selecting note templates.
Package viewer is the main markdown viewer/editor TUI component.
Package viewer is the main markdown viewer/editor TUI component.

Jump to